# collibra-importer
<p>The Import API is an efficient way to load large volumes of data into the Collibra Data Governance Center. The API can automatically differentiate between creating and updating data.</p>

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import collibra_importer
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import collibra_importer
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import collibra_importer
from collibra_importer.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost/rest/2.0
# See configuration.py for a list of all supported configuration parameters.
configuration = collibra_importer.Configuration(
    host = "http://localhost/rest/2.0"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = collibra_importer.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Configure Bearer authorization (JWT): bearerAuth
configuration = collibra_importer.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)


# Enter a context with an instance of the API client
with collibra_importer.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = collibra_importer.ImportApi(api_client)
    synchronization_id = 'synchronization_id_example' # str | The synchronization id of the operation.

    try:
        # Removes all cache entries corresponding to the provided synchronization id.
        api_instance.evict_synchronization_cache(synchronization_id)
    except ApiException as e:
        print("Exception when calling ImportApi->evict_synchronization_cache: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/rest/2.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ImportApi* | [**evict_synchronization_cache**](docs/ImportApi.md#evict_synchronization_cache) | **DELETE** /import/synchronize/{synchronizationId}/evict | Removes all cache entries corresponding to the provided synchronization id.
*ImportApi* | [**exists**](docs/ImportApi.md#exists) | **GET** /import/synchronize/exists/{synchronizationId} | Checks whether given synchronization id already exists.
*ImportApi* | [**find_synchronization_infos**](docs/ImportApi.md#find_synchronization_infos) | **GET** /import/synchronize | Returns synchronization information matching the given search criteria.
*ImportApi* | [**import_csv_in_job**](docs/ImportApi.md#import_csv_in_job) | **POST** /import/csv-job | Starts import from the CSV file in job (asynchronously).
*ImportApi* | [**import_excel_in_job**](docs/ImportApi.md#import_excel_in_job) | **POST** /import/excel-job | Starts import from the Excel file in job (asynchronously).
*ImportApi* | [**import_json_in_job**](docs/ImportApi.md#import_json_in_job) | **POST** /import/json-job | Starts import from the JSON file in job (asynchronously).
*ImportApi* | [**remove_synchronization**](docs/ImportApi.md#remove_synchronization) | **DELETE** /import/synchronize/{synchronizationId} | Removes all information about synchronization process corresponding to provided synchronization id.
*ImportApi* | [**synchronize_batch_csv_in_job**](docs/ImportApi.md#synchronize_batch_csv_in_job) | **POST** /import/synchronize/{synchronizationId}/batch/csv-job | Starts batch synchronization from the CSV file in job (asynchronously).
*ImportApi* | [**synchronize_batch_excel_in_job**](docs/ImportApi.md#synchronize_batch_excel_in_job) | **POST** /import/synchronize/{synchronizationId}/batch/excel-job | Starts batch synchronization from the Excel file in job (asynchronously).
*ImportApi* | [**synchronize_batch_json_in_job**](docs/ImportApi.md#synchronize_batch_json_in_job) | **POST** /import/synchronize/{synchronizationId}/batch/json-job | Starts batch synchronization from the JSON file in job (asynchronously).
*ImportApi* | [**synchronize_csv_in_job**](docs/ImportApi.md#synchronize_csv_in_job) | **POST** /import/synchronize/{synchronizationId}/csv-job | Starts full synchronization from the CSV file in job (asynchronously).
*ImportApi* | [**synchronize_excel_in_job**](docs/ImportApi.md#synchronize_excel_in_job) | **POST** /import/synchronize/{synchronizationId}/excel-job | Starts full synchronization from the Excel file in job (asynchronously).
*ImportApi* | [**synchronize_finalize_in_job**](docs/ImportApi.md#synchronize_finalize_in_job) | **POST** /import/synchronize/{synchronizationId}/finalize/job | Starts synchronization finalization in job (asynchronously).
*ImportApi* | [**synchronize_json_in_job**](docs/ImportApi.md#synchronize_json_in_job) | **POST** /import/synchronize/{synchronizationId}/json-job | Starts full synchronization from the JSON file in job (asynchronously).
*ImportResultsApi* | [**find_import_errors**](docs/ImportResultsApi.md#find_import_errors) | **GET** /import/results/{jobId}/errors | List the errors of a finished import job
*ImportResultsApi* | [**get_import_job_summary**](docs/ImportResultsApi.md#get_import_job_summary) | **GET** /import/results/{jobId}/summary | Retrieve a summary of a finished import job


## Documentation For Models

 - [AssetIdentifier](docs/AssetIdentifier.md)
 - [AssetImportCommand](docs/AssetImportCommand.md)
 - [AssetTypeIdentifier](docs/AssetTypeIdentifier.md)
 - [AttributeValue](docs/AttributeValue.md)
 - [CategoryReference](docs/CategoryReference.md)
 - [CommunityIdentifier](docs/CommunityIdentifier.md)
 - [CommunityImportCommand](docs/CommunityImportCommand.md)
 - [ComplexRelationIdentifier](docs/ComplexRelationIdentifier.md)
 - [ComplexRelationImportCommand](docs/ComplexRelationImportCommand.md)
 - [ComplexRelationTypeIdentifier](docs/ComplexRelationTypeIdentifier.md)
 - [DomainIdentifier](docs/DomainIdentifier.md)
 - [DomainImportCommand](docs/DomainImportCommand.md)
 - [DomainTypeIdentifier](docs/DomainTypeIdentifier.md)
 - [ExternalIdentifier](docs/ExternalIdentifier.md)
 - [FindSynchronizationRequest](docs/FindSynchronizationRequest.md)
 - [ImportCommandReference](docs/ImportCommandReference.md)
 - [ImportCounters](docs/ImportCounters.md)
 - [ImportCsvInJobRequest](docs/ImportCsvInJobRequest.md)
 - [ImportError](docs/ImportError.md)
 - [ImportErrorPagedResponse](docs/ImportErrorPagedResponse.md)
 - [ImportExcelInJobRequest](docs/ImportExcelInJobRequest.md)
 - [ImportJsonInJobRequest](docs/ImportJsonInJobRequest.md)
 - [ImportSummary](docs/ImportSummary.md)
 - [InlineObject](docs/InlineObject.md)
 - [InlineObject1](docs/InlineObject1.md)
 - [InlineObject2](docs/InlineObject2.md)
 - [InlineObject3](docs/InlineObject3.md)
 - [InlineObject4](docs/InlineObject4.md)
 - [InlineObject5](docs/InlineObject5.md)
 - [InlineObject6](docs/InlineObject6.md)
 - [InlineObject7](docs/InlineObject7.md)
 - [InlineObject8](docs/InlineObject8.md)
 - [InlineObject9](docs/InlineObject9.md)
 - [Job](docs/Job.md)
 - [MappingIdentifier](docs/MappingIdentifier.md)
 - [MappingImportCommand](docs/MappingImportCommand.md)
 - [Owner](docs/Owner.md)
 - [PagedResponseImportError](docs/PagedResponseImportError.md)
 - [PagedResponseSynchronizationInfo](docs/PagedResponseSynchronizationInfo.md)
 - [ResourceTypeSummary](docs/ResourceTypeSummary.md)
 - [StatusIdentifier](docs/StatusIdentifier.md)
 - [SubcategorySummary](docs/SubcategorySummary.md)
 - [SynchronizationBatchCsvInJobRequest](docs/SynchronizationBatchCsvInJobRequest.md)
 - [SynchronizationBatchExcelInJobRequest](docs/SynchronizationBatchExcelInJobRequest.md)
 - [SynchronizationBatchJsonInJobRequest](docs/SynchronizationBatchJsonInJobRequest.md)
 - [SynchronizationCsvInJobRequest](docs/SynchronizationCsvInJobRequest.md)
 - [SynchronizationExcelInJobRequest](docs/SynchronizationExcelInJobRequest.md)
 - [SynchronizationFinalizationRequest](docs/SynchronizationFinalizationRequest.md)
 - [SynchronizationInfo](docs/SynchronizationInfo.md)
 - [SynchronizationJsonInJobRequest](docs/SynchronizationJsonInJobRequest.md)
 - [UserGroupIdentifier](docs/UserGroupIdentifier.md)
 - [UserIdentifier](docs/UserIdentifier.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## bearerAuth

- **Type**: Bearer authentication (JWT)


## Author




